@@ -708,6 +708,37 @@ class CollectionModelTestCase(unittest.TestCase):
 
         TestModel.destroy()
 
+    def test_hash_index_on_model_field(self):
+
+        class TestModel(CollectionModel):
+
+            username_hash_index = HashIndex(fields=['username'])
+
+            username = CharField(required=True, null=False)
+
+        TestModel.init()
+
+        has_exception = False
+
+        try:
+            model1 = TestModel()
+            model1.username = 'aoo'
+            model1.save()
+
+            model2 = TestModel()
+            model2.username = 'aoo'
+            model2.save()
+        except:
+            has_exception = True
+
+        self.assertTrue(has_exception)
+
+        all_created_models = TestModel.objects.all()
+
+        self.assertEqual(len(all_created_models), 1)
+
+        TestModel.destroy()
+
 
 class CollectionModelManagerTestCase(unittest.TestCase):
     def setUp(self):
@@ -1423,6 +1454,45 @@ class IndexTestCase(ExtendedTestCase):
 
         index.delete()
 
+    def test_overwrite_index_definition(self):
+
+        index = Index(self.test_1_col, HashIndex(fields=[
+            'username'
+        ]))
+
+        index.save()
+
+        doc1 = self.test_1_col.create_document()
+        doc1.username = 'test'
+        doc1.save()
+
+        has_exception = False
+
+        doc2 = self.test_1_col.create_document()
+        doc2.username = 'test'
+
+        try:
+            doc2.save()
+        except:
+            has_exception = True
+
+        self.assertTrue(has_exception)
+
+        index.index_type_obj.unique = False
+
+        index.overwrite()
+
+        has_exception = False
+
+        try:
+            doc2.save()
+        except:
+            has_exception = True
+
+        self.assertFalse(has_exception)
+
+        index.delete()
+
 
 class UserTestCase(ExtendedTestCase):
     def setUp(self):
